/*
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

require([
    'aps/load',
    'aps/xhr',
    'app/common',
    'app/messages',
    'dijit/registry',
    'dojox/mvc/at',
    'dojox/mvc/getStateful',
    'dojox/mvc/getPlainValue'
], function (
    load,
    xhr,
    common,
    messages,
    registry,
    at,
    getStateful,
    getPlainValue
) {
    var user = aps.context.vars.user,
        model = getStateful({
            password: ''
        });

    load(["aps/PageContainer", {id: "apsPageContainer"}, [
        ["aps/FieldSet", {
            id: "createFieldSet",
            title: _("Activate user")
        }, [
            ["aps/Output", {
                id: "login",
                label: _("Login"),
                value: user.endUserLogin
            }],
            ["./js/widgets/Password.js", {
                id: "password",
                label: _("Password"),
                value: at(model, "password"),
                hint: _("7-characters minimum, including letters in different cases and digits"),
                required: true
            }]
        ]]
    ]]).then(function () {
        aps.app.onSubmit = function () {
            messages.removeAll();
            var fieldSet = registry.byId("createFieldSet");
            if (!fieldSet.validate()) {
                messages.displayMessage(_("Incorrect or empty field value(s). Please retype info in the highlighted fields."), "error");
                aps.apsc.cancelProcessing();
                return;
            }

            xhr("/aps/2/resources/" + user.aps.id + "/activateAccount", {
                method: "POST",
                headers: {"Content-Type": "application/json"},
                data: JSON.stringify(getPlainValue(model))
            }).then(function () {
                aps.apsc.gotoView(common.getRelatedViewId('list'));
            }, messages.displayError);
        };
    });

    aps.app.onCancel = function () {
        aps.apsc.gotoView(common.getRelatedViewId('list'));
    };
});