/**
 * @Copyright © 2002-2020 Acronis International GmbH. All rights reserved
 */

/*
 System phrases for localization parser
 _("All");
 */
define([
    "aps/i18n",
    "aps/xhr",
    "dijit/registry",
    "dojo/Deferred",
    "dojo/_base/lang",
    "dojox/mvc/equals",
    "aps/ResourceStore",
    "dojox/mvc/getStateful"
], function (
    _,
    xhr,
    registry,
    Deferred,
    lang,
    equals,
    Store,
    getStateful
) {
    var USER_MANAGED_OFFERING_ITEMS_COUNTERS = [        "NotarizationsCount",
        "EsignaturesCount",
        "NotaryUsage",
        "PgPackAdvBackupServersCount",
        "PwPackAdvBackupServersCount",
        "PgPackAdvBackupVmsCount",
        "PwPackAdvBackupVmsCount",
        "PgPackAdvBackupWebHostingServersCount",
        "PwPackAdvBackupWebHostingServersCount",
        "PgPackAdvBackupWorkstationsCount",
        "PwPackAdvBackupWorkstationsCount",
        "PgPackAdvManagementCount",
        "PwPackAdvManagementCount",
        "PgPackAdvSecurityCount",
        "PwPackAdvSecurityCount",
        "EsignaturesZTCCount",
        "NotarizationsZTCCount",

        // ui_js_common_user_managed this code is used for code generation, do not remove!
        "WorkstationCount",
        "ServerCount",
        "VmCount",
        "MobileDeviceCount",
        "WebHostingServerCount",
        "WebsiteCount",
        "HostedExchangeCount",
        "StorageUsage"
    ];

    return {
        APP_ID: "http://www.acronis.com/aps/cloud-backup-v1",
        SERVICE_TITLE: _("Backup"),
        BYTES_IN_GB: 1024 * 1024 * 1024,
        QUOTA_UNLIMITED_VALUE: -1,
        USER_MANAGED_OFFERING_ITEMS_COUNTERS: USER_MANAGED_OFFERING_ITEMS_COUNTERS,
        getCountersToOfferingItems: function () {
            var aliases = {
                    'O365SeatsCount': 'MailboxCount',
                    'PublicIpsCount': 'PublicIPsCount'
                },
                counters = {                    "FilesStorageUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Files Cloud Storage (Acronis)")
                    },
                    "FilesUsersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Files Cloud Users (Acronis)")
                    },
                    "NotarizationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Notary - Notarizations (Ethereum)")
                    },
                    "EsignaturesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Notary - eSignatures (Ethereum)")
                    },
                    "FCNotarizationsEthereum": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Files Cloud Notarizations (Ethereum)")
                    },
                    "FCEsignaturesEthereum": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Files Cloud eSignatures (Ethereum)")
                    },
                    "NotaryUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        legendSchema: 'storage',
label: _("Notary - Notary storage {unit}")
                    },
                    "CPBStdGsuiteSeatsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} seats protected"),
                            unlimitedLegend: _("${usage} seats protected"),
                            zeroUsageLegend: _("${limit} seats can be protected")
                        },
                        label: _("Cyber Backup Standard - G Suite seats")
                    },
                    "CPBStdGsuiteGoogleTeamDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - G Suite Shared Drive")
                    },
                    "CPBStdGsuiteGoogleMail": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Gmail (incl. Calendar, Contacts)")
                    },
                    "CPBStdGsuiteGoogleDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Google Drive")
                    },
                    "CPBStdO365Mailboxes": {
                        iconClass: "i-mail-o--24",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Microsoft 365 Mailboxes")
                    },
                    "CPBStdO365SeatsCount": {
                        iconClass: "i-mailboxes-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} seats protected"),
                            unlimitedLegend: _("${usage} seats protected"),
                            zeroUsageLegend: _("${limit} seats can be protected")
                        },
                        label: _("Cyber Backup Standard - Microsoft 365 Seats")
                    },
                    "CPBStdMobileDeviceCount": {
                        iconClass: "i-mobile-devices-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} devices protected"),
                            unlimitedLegend: _("${usage} devices protected"),
                            zeroUsageLegend: _("${limit} devices can be protected")
                        },
                        label: _("Cyber Backup Standard - Mobile Devices")
                    },
                    "CPBStdO365SharePointSitesCount": {
                        iconClass: "i-o-365-sharepoint-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} sites protected"),
                            unlimitedLegend: _("${usage} sites protected"),
                            zeroUsageLegend: _("${limit} sites can be protected")
                        },
                        label: _("Cyber Backup Standard - Microsoft SharePoint Online Sites")
                    },
                    "CPBStdO365TeamsCount": {
                        iconClass: "i-office-365-teams-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} teams protected"),
                            unlimitedLegend: _("${usage} teams protected"),
                            zeroUsageLegend: _("${limit} teams can be protected")
                        },
                        label: _("Cyber Backup Standard - Microsoft Teams")
                    },
                    "CPBStdO365OneDrive": {
                        iconClass: "i-one-drive--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Microsoft OneDrive")
                    },
                    "CPBStdServerCount": {
                        iconClass: "i-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Backup Standard - Servers")
                    },
                    "CPBStdVmCount": {
                        iconClass: "i-virtual-machines-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Backup Standard - Virtual Machines")
                    },
                    "CPBStdWebHostingServerCount": {
                        iconClass: "i-web-hosting-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} servers protected"),
                            unlimitedLegend: _("${usage} servers protected"),
                            zeroUsageLegend: _("${limit} servers can be protected")
                        },
                        label: _("Cyber Backup Standard - Web Hosting Servers")
                    },
                    "CPBStdWebsiteCount": {
                        iconClass: "i-website-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} websites protected"),
                            unlimitedLegend: _("${usage} websites protected"),
                            zeroUsageLegend: _("${limit} websites can be protected")
                        },
                        label: _("Cyber Backup Standard - Websites")
                    },
                    "CPBStdWorkstationCount": {
                        iconClass: "i-workstations-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Backup Standard - Workstations")
                    },
                    "CPCloudServersCount": {
                        iconClass: "i-cloud-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} cloud servers"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} cloud servers available")
                        },
                        label: _("Disaster Recovery - Cloud Servers")
                    },
                    "CPStorageUsage": {
                        iconClass: "i-cloud-storage-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${limit} ${limitUnit} available")
                        },
                        label: _("Cloud Storage {unit}")
                    },
                    "CPComputePointsCount": {
                        iconClass: "i-cp-used-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} compute points"),
                            unlimitedLegend: _("${usage} compute points used"),
                            zeroUsageLegend: _("${limit} compute points available")
                        },
                        label: _("Disaster Recovery - Compute Points")
                    },
                    "CPDrStorageUsage": {
                        iconClass: "i-dr-storage-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${limit} ${limitUnit} available")
                        },
                        label: _("Disaster Recovery Storage")
                    },
                    "CPInternetAccess": {
                        iconClass: "i-internet-access-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Disaster Recovery - Internet Access")
                    },
                    "CPPAdvServerCount": {
                        iconClass: "i-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Advanced - Servers")
                    },
                    "CPPAdvVmCount": {
                        iconClass: "i-virtual-machines-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Advanced - Virtual Machines")
                    },
                    "CPPAdvWebHostingServerCount": {
                        iconClass: "i-web-hosting-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} servers protected"),
                            unlimitedLegend: _("${usage} servers protected"),
                            zeroUsageLegend: _("${limit} servers can be protected")
                        },
                        label: _("Cyber Protect Advanced - Web Hosting Servers")
                    },
                    "CPPAdvWorkstationCount": {
                        iconClass: "i-workstations-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Advanced - Workstations")
                    },
                    "CPPEssServerCount": {
                        iconClass: "i-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Essentials - Servers")
                    },
                    "CPPEssVmCount": {
                        iconClass: "i-virtual-machines-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Essentials - Virtual Machines")
                    },
                    "CPPEssWorkstationCount": {
                        iconClass: "i-workstations-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Essentials - Workstations")
                    },
                    "CPPStdServerCount": {
                        iconClass: "i-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Standard - Servers")
                    },
                    "CPPStdVmCount": {
                        iconClass: "i-virtual-machines-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Standard - Virtual Machines")
                    },
                    "CPPStdWebHostingServerCount": {
                        iconClass: "i-web-hosting-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} servers protected"),
                            unlimitedLegend: _("${usage} servers protected"),
                            zeroUsageLegend: _("${limit} servers can be protected")
                        },
                        label: _("Cyber Protect Standard - Web Hosting Servers")
                    },
                    "CPPStdWorkstationCount": {
                        iconClass: "i-workstations-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Protect Standard - Workstations")
                    },
                    "CPPublicIPsCount": {
                        iconClass: "i-public-ips-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} public IP addresses"),
                            unlimitedLegend: _("${usage} public IP addresses used"),
                            zeroUsageLegend: _("${limit} public IP addresses available")
                        },
                        label: _("Disaster Recovery - Public IP Addresses")
                    },
                    "CBBStdGsuiteSeatsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} seats protected"),
                            unlimitedLegend: _("${usage} seats protected"),
                            zeroUsageLegend: _("${limit} seats can be protected")
                        },
                        label: _("Cyber Backup Standard - G Suite seats")
                    },
                    "CBBStdGsuiteGoogleTeamDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - G Suite Shared Drive")
                    },
                    "CBBStdGsuiteGoogleMail": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Gmail (incl. Calendar, Contacts)")
                    },
                    "CBBStdGsuiteGoogleDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Google Drive")
                    },
                    "CBBStdO365Mailboxes": {
                        iconClass: "i-mail-o--24",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Microsoft 365 Mailboxes")
                    },
                    "CBBStdO365SeatsCount": {
                        iconClass: "i-mailboxes-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} seats protected"),
                            unlimitedLegend: _("${usage} seats protected"),
                            zeroUsageLegend: _("${limit} seats can be protected")
                        },
                        label: _("Cyber Backup Standard - Microsoft 365 Seats")
                    },
                    "CBBStdO365SharePointSitesCount": {
                        iconClass: "i-o-365-sharepoint-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} sites protected"),
                            unlimitedLegend: _("${usage} sites protected"),
                            zeroUsageLegend: _("${limit} sites can be protected")
                        },
                        label: _("Cyber Backup Standard - Microsoft SharePoint Online Sites")
                    },
                    "CBBStdO365TeamsCount": {
                        iconClass: "i-office-365-teams-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} teams protected"),
                            unlimitedLegend: _("${usage} teams protected"),
                            zeroUsageLegend: _("${limit} teams can be protected")
                        },
                        label: _("Cyber Backup Standard - Microsoft Teams")
                    },
                    "CBBStdMobileDeviceCount": {
                        iconClass: "i-mobile-devices-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} devices protected"),
                            unlimitedLegend: _("${usage} devices protected"),
                            zeroUsageLegend: _("${limit} devices can be protected")
                        },
                        label: _("Cyber Backup Standard - Mobile Devices")
                    },
                    "CBBStdO365OneDrive": {
                        iconClass: "i-one-drive--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("Enabled"),
                            unlimitedLegend: _("Enabled"),
                            zeroUsageLegend: _("Enabled")
                        },
                        label: _("Cyber Backup Standard - Microsoft OneDrive")
                    },
                    "CBBStdServerCount": {
                        iconClass: "i-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} servers protected"),
                            unlimitedLegend: _("${usage} servers protected"),
                            zeroUsageLegend: _("${limit} servers can be protected")
                        },
                        label: _("Cyber Backup Standard - Servers")
                    },
                    "CBBStdVmCount": {
                        iconClass: "i-virtual-machines-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Backup Standard - Virtual Machines")
                    },
                    "CBBStdWebHostingServerCount": {
                        iconClass: "i-web-hosting-server-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} servers protected"),
                            unlimitedLegend: _("${usage} servers protected"),
                            zeroUsageLegend: _("${limit} servers can be protected")
                        },
                        label: _("Cyber Backup Standard - Web Hosting Servers")
                    },
                    "CBBStdWebsiteCount": {
                        iconClass: "i-website-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} websites protected"),
                            unlimitedLegend: _("${usage} websites protected"),
                            zeroUsageLegend: _("${limit} websites can be protected")
                        },
                        label: _("Cyber Backup Standard - Websites")
                    },
                    "CBBStdWorkstationCount": {
                        iconClass: "i-workstations-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} of ${limit} machines protected"),
                            unlimitedLegend: _("${usage} machines protected"),
                            zeroUsageLegend: _("${limit} machines can be protected")
                        },
                        label: _("Cyber Backup Standard - Workstations")
                    },
                    "CBStorageUsage": {
                        iconClass: "i-cloud-storage-o--16",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${limit} ${limitUnit} available")
                        },
                        label: _("Cloud Storage {unit}")
                    },
                    "CBLocalStorageUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("CB Local Storage (Acronis)")
                    },
                    "PgPackAdvBackupServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Servers (Per GB)")
                    },
                    "PwPackAdvBackupServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Servers (Per Workload)")
                    },
                    "PgPackAdvBackupVmsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Virtual machines (Per GB)")
                    },
                    "PwPackAdvBackupVmsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Virtual machines (Per Workload)")
                    },
                    "PgPackAdvBackupWebHostingServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Web hosting servers (Per GB)")
                    },
                    "PwPackAdvBackupWebHostingServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Web hosting servers (Per Workload)")
                    },
                    "PgPackAdvBackupWorkstationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Workstations (Per GB)")
                    },
                    "PwPackAdvBackupWorkstationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Backup - Workstations (Per Workload)")
                    },
                    "PgBaseDrBase": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Disaster Recovery (Base) (Per GB)")
                    },
                    "PgBaseAdvDrCloudServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Cloud servers (Per GB)")
                    },
                    "PgBaseAdvDrComputePoints": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Compute points (Per GB)")
                    },
                    "PgBaseAdvDrInternetAccess": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Internet access (Per GB)")
                    },
                    "PgBaseAdvDrPublicIpsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Public IP addresses (Per GB)")
                    },
                    "PwBaseDrBase": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Disaster Recovery (Base) (Per Workload)")
                    },
                    "PgPackAdvManagementCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Management (Per GB)")
                    },
                    "PwPackAdvManagementCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Management (Per Workload)")
                    },
                    "PgPackAdvSecurityCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Security (Per GB)")
                    },
                    "PwPackAdvSecurityCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Advanced Pack - Advanced Security (Per Workload)")
                    },
                    "PgBaseSecondaryWorkstationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Workstations (included features) (Per GB)")
                    },
                    "PgBaseWorkstationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Workstations (Per GB)")
                    },
                    "PgBaseWebsitesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Websites (Per GB)")
                    },
                    "PgBaseSecondaryWebHostingServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Web hosting servers (included features) (Per GB)")
                    },
                    "PgBaseWebHostingServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Web hosting servers (Per GB)")
                    },
                    "PgBaseSecondaryVmsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Virtual machines (included features) (Per GB)")
                    },
                    "PgBaseVmsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Virtual machines (Per GB)")
                    },
                    "PgBaseSecondaryServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Servers (included features) (Per GB)")
                    },
                    "PgBaseServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Servers (Per GB)")
                    },
                    "PgBaseM365Onedrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - OneDrive (Per GB)")
                    },
                    "PgBaseMobilesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Mobile devices (Per GB)")
                    },
                    "PgBaseM365TeamsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft Teams (Per GB)")
                    },
                    "PgBaseM365SharepointSitesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft SharePoint Online sites (Per GB)")
                    },
                    "PgBaseHostedExchangeCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft Hosted Exchange mailboxes (Per GB)")
                    },
                    "PgBaseM365SeatsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft 365 seats (Per GB)")
                    },
                    "PgBaseM365Mailboxes": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Mailboxes (Per GB)")
                    },
                    "PgBaseGoogleTeamDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Google Workspace Shared Drive (Per GB)")
                    },
                    "PgBaseGworkspaceSeatsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Google Workspace seats (Per GB)")
                    },
                    "PgBaseGoogleDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Google Drive (Per GB)")
                    },
                    "PgBaseGoogleMail": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Gmail (incl. Calendar, Contacts) (Per GB)")
                    },
                    "PwBaseAdvDrCloudServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Cloud servers (Per Workload)")
                    },
                    "PwBaseSecondaryWorkstationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Workstations (included features) (Per Workload)")
                    },
                    "PwBaseWorkstationsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Workstations (Per Workload)")
                    },
                    "PwBaseWebsitesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Websites (Per Workload)")
                    },
                    "PwBaseSecondaryWebHostingServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Web hosting servers (included features) (Per Workload)")
                    },
                    "PwBaseWebHostingServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Web hosting servers (Per Workload)")
                    },
                    "PwBaseSecondaryVmsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Virtual machines (included features) (Per Workload)")
                    },
                    "PwBaseVmsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Virtual machines (Per Workload)")
                    },
                    "PwBaseSecondaryServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _("${usage} ${usageUnit} used"),
                            unlimitedLegend: _("${usage} ${usageUnit} used"),
                            zeroUsageLegend: _("${usage} ${usageUnit} used")
                        },
                        label: _("Cyber Protect Cloud - Servers (included features) (Per Workload)")
                    },
                    "PwBaseServersCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Servers (Per Workload)")
                    },
                    "PwBaseAdvDrComputePoints": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Compute points (Per Workload)")
                    },
                    "PwBaseM365Onedrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - OneDrive (Per Workload)")
                    },
                    "PwBaseMobilesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Mobile devices (Per Workload)")
                    },
                    "PwBaseM365TeamsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft Teams (Per Workload)")
                    },
                    "PwBaseM365SharepointSitesCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft SharePoint Online sites (Per Workload)")
                    },
                    "PwBaseHostedExchangeCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft Hosted Exchange mailboxes (Per Workload)")
                    },
                    "PwBaseM365SeatsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Microsoft 365 seats (Per Workload)")
                    },
                    "PwBaseM365Mailboxes": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Mailboxes (Per Workload)")
                    },
                    "PwBaseGoogleTeamDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Google Workspace Shared Drive (Per Workload)")
                    },
                    "PwBaseGworkspaceSeatsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Google Workspace seats (Per Workload)")
                    },
                    "PwBaseGoogleDrive": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Google Drive (Per Workload)")
                    },
                    "PwBaseGoogleMail": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Gmail (incl. Calendar, Contacts) (Per Workload)")
                    },
                    "PwBaseAdvDrInternetAccess": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Internet access (Per Workload)")
                    },
                    "PwBaseAdvDrPublicIpsCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Public IP addresses (Per Workload)")
                    },
                    "PgBaseStorageUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Backup storage (Per GB)")
                    },
                    "PgBaseAdvDrStorageUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Disaster recovery storage (Per GB)")
                    },
                    "PwBaseStorageUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        legendSchema: 'storage',
label: _("Cyber Protect Cloud - Backup storage (Per Workload) {unit}")
                    },
                    "PwBaseAdvDrStorageUsage": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Cyber Protect Cloud - Disaster recovery storage (Per Workload)")
                    },
                    "DrivesShippedFromCloudCountItemH": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Physical Data Shipping - From the cloud")
                    },
                    "DrivesShippedToCloudCountItemH": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Physical Data Shipping - To the cloud")
                    },
                    "EsignaturesZTCCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Notary - eSignatures (Zero-Trust Consortium)")
                    },
                    "NotarizationsZTCCount": {
                        iconClass: "",
                        legend: {
                            noneLegend: _(""),
                            limitedLegend: _(""),
                            unlimitedLegend: _(""),
                            zeroUsageLegend: _("")
                        },
                        label: _("Notary - Notarizations (Zero-Trust Consortium)")
                    }

                    // ui_js_common_counter_data [this code is used for code generation, do not remove!]
                },
                legacyCounters = {
                    'StorageUsage': {
                        iconClass: 'i-cloud-storage-o--16',
                        legendSchema: 'storage',
                        label: _('Cloud Storage {unit}')
                    },
                    'WorkstationCount': {
                        iconClass: 'i-workstations-o--16',
                        legendSchema: 'machines',
                        label: _('Workstations')
                    },
                    'ServerCount': {
                        iconClass: 'i-server-o--16',
                        legendSchema: 'machines',
                        label: _('Servers')
                    },
                    'VmCount': {
                        iconClass: 'i-virtual-machines-o--16',
                        legendSchema: 'machines',
                        label: _('Virtual Machines')
                    },
                    'MobileDeviceCount': {
                        iconClass: 'i-mobile-devices-o--16',
                        legendSchema: 'devices',
                        label: _('Mobile Devices')
                    },
                    'WebHostingServerCount': {
                        iconClass: 'i-web-hosting-server-o--16',
                        legendSchema: 'servers',
                        label: _('Web Hosting Servers')
                    },
                    'WebsiteCount': {
                        iconClass: 'i-website-o--16',
                        legendSchema: 'servers',
                        label: _('Websites')
                    },
                    'ComputePointsCount': {
                        iconClass: 'i-cp-used-o--16',
                        legendSchema: 'unit',
                        label: _('Disaster Recovery - Compute Points')
                    },
                    'LocalStorageUsage': {
                        iconClass: 'i-local-backup-o--16',
                        legendSchema: 'storage',
                        label: _('Local Storage')
                    },
                    'MailboxCount': {
                        iconClass: 'i-mailboxes-o--16',
                        legendSchema: 'unit',
                        label: _('Microsoft 365 Seats')
                    },
                    'DrStorageUsage': {
                        iconClass: 'i-dr-storage-o--16',
                        legendSchema: 'storage',
                        label: _('Disaster Recovery Storage')
                    },
                    'PublicIPsCount': {
                        iconClass: 'i-public-ips-o--16',
                        legendSchema: 'unit',
                        label: _('Disaster Recovery - Public IP Addresses')
                    },
                    'CloudServersCount': {
                        iconClass: 'i-cloud-server-o--16',
                        legendSchema: 'unit',
                        label: _('Disaster Recovery - Cloud Servers')
                    },
                    'InternetAccess': {
                        iconClass: 'i-internet-access-o--16',
                        legendSchema: 'feature',
                        label: _('Disaster Recovery - Internet Access')
                    },
                    'O365Mailboxes': {
                        iconClass: 'i-mail-o--24',
                        legendSchema: 'feature',
                        label: _('Microsoft 365 Mailboxes')
                    },
                    'O365OneDrive': {
                        iconClass: 'i-one-drive--16',
                        legendSchema: 'feature',
                        label: _('Microsoft OneDrive')
                    },
                    'O365SharePointSitesCount': {
                        iconClass: 'i-o-365-sharepoint-o--16',
                        legendSchema: 'feature',
                        label: _('Microsoft SharePoint Online Sites')
                    },
                    'GsuiteGoogleTeamDrive': {
                        iconClass: 'i-g-suite-team--16',
                        legendSchema: 'feature',
                        label: _('G Suite Shared Drive')
                    },
                    'GsuiteGoogleMail': {
                        iconClass: 'i-gmail--16',
                        legendSchema: 'feature',
                        label: _('Gmail (incl. Calendar, Contacts)')
                    },
                    'GsuiteGoogleDrive': {
                        iconClass: 'i-my-drive--16',
                        legendSchema: 'feature',
                        label: _('Google Drive')
                    },
                    'GsuiteSeatsCount': {
                        iconClass: 'i-g-suite--16',
                        legendSchema: 'unit',
                        label: _('G Suite Seats')
                    },
                    'O365TeamsCount': {
                        iconClass: 'i-office-365-teams--16',
                        legendSchema: 'unit',
                        label: _('Microsoft Teams')
                    },
                    "HostedExchangeCount": {
                        iconClass: "i-hosted-exchange-o--16",
                        legendSchema: 'mailboxes',
                        label: _("Microsoft Hosted Exchange Mailboxes")
                    }
                },
                legacyEditions = ['Adv', 'Dre', 'PAdv', 'PDre', 'P'];

            for (var alias in aliases) {
                var counterName = aliases[alias];
                legacyCounters[alias] = lang.clone(legacyCounters[counterName]);
            }

            for (var counterName in counters) {
                let counter = counters[counterName]
                if (window.countersMeta.hasOwnProperty(counterName)) {
                    counter.meta = window.countersMeta[counterName];
                    if (counter.meta['unit_of_measure'] === 'b') {
                        counter.legendSchema = 'storage';
                    } else if (counter.meta['is_feature']) {
                        counter.legendSchema = 'feature';
                    }
                } else {
                    counter.meta = {}
                }
            }


            for (var originalName in legacyCounters) {
                counters[originalName] = legacyCounters[originalName];
                legacyEditions.forEach(function (editionPrefix) {
                    counters[editionPrefix + originalName] = lang.clone(legacyCounters[originalName]);
                })
            }

            return counters;
        },

        ALL_COUNTERS_MAP: null,

        COUNTERS_LEGEND_SCHEMAS: function () {
            return {
                'feature': {},
                'unit': {
                    noneLegend: _("None"),
                    limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                    unlimitedLegend: _("${usage} ${usageUnit} used")
                },
                'storage': {
                    noneLegend: _("None"),
                    limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                    unlimitedLegend: _("${usage} ${usageUnit} used")
                },
                'machines': {
                    limitedLegend: _("${usage} of ${limit} machines protected"),
                    zeroUsageLegend: _("${limit} machines can be protected"),
                    unlimitedLegend: _("${usage} machines protected")
                },
                'devices': {
                    limitedLegend: _("${usage} of ${limit} devices protected"),
                    zeroUsageLegend: _("${limit} devices can be protected"),
                    unlimitedLegend: _("${usage} devices protected")
                },
                'servers': {
                    limitedLegend: _("${usage} of ${limit} servers protected"),
                    zeroUsageLegend: _("${limit} servers can be protected"),
                    unlimitedLegend: _("${usage} servers protected")
                },
                'websites': {
                    limitedLegend: _("${usage} of ${limit} websites protected"),
                    zeroUsageLegend: _("${limit} websites can be protected"),
                    unlimitedLegend: _("${usage} websites protected")
                }
            }
        },

        // Use * to display all counters in specific area,
        // use ['Counter1', ... , 'CounterN'] to display some specific list
        COUNTERS_AVAILABILITY_MAP: {
            'resources_tile_ccpv2': '*',
            'quota_list_view_ccpv2': [],
            'user_quotas': USER_MANAGED_OFFERING_ITEMS_COUNTERS,
            'devices_count_ccpv2': USER_MANAGED_OFFERING_ITEMS_COUNTERS.filter(function (counterName) {
                return counterName !== 'StorageUsage';
            }),
            'storage_usage_only': ["StorageUsage"],
            'quota_controls_ccpv1_users_list': [
                'WorkstationCount',
                'ServerCount',
                'VmCount',
                'MobileDeviceCount',
                'WebHostingServerCount',
                'WebsiteCount'
            ],
            'quota_controls_ccpv1_new_user': USER_MANAGED_OFFERING_ITEMS_COUNTERS,
            'quota_controls_ccpv1_edit_user': USER_MANAGED_OFFERING_ITEMS_COUNTERS,
            'quota_controls_ccpv1_view_user': USER_MANAGED_OFFERING_ITEMS_COUNTERS
        },

        USER_AREAS: {
            'user_quotas': true,
            'quota_controls_ccpv1_new_user': true,
            'quota_controls_ccpv1_edit_user': true,
            'quota_controls_ccpv1_view_user': true
        },

        getBackupAccountResources: function (tenant) {
            var self = this;
            var deferred = new Deferred();
            xhr('/aps/2/resources/' + tenant.aps.subscription + '/resources')
                .then(function (subscriptionResources) {
                    var availableResources = [];
                    subscriptionResources.forEach(function (resource) {
                        if (self.isBackupAccountResource(resource)) {
                            availableResources.push(resource);
                        }
                    });
                    deferred.resolve(availableResources);
                }, deferred.reject);
            return deferred;
        },

        getBackupUserData: function(user) {
            var deferred = new Deferred();
            if (user.userId) {
                deferred.resolve(user);
            } else {
                xhr.get('/aps/2/resources/' + user.aps.id + '/getUser')
                    .then(function (user) {
                        deferred.resolve(user);
                    }, deferred.reject);
            }
            return deferred;
        },

        fetchTenantUser: function(tenantId, userApsId) {
            var deferred = new Deferred();
            xhr.get('/aps/2/resources/' + tenantId + '/users')
              .then(function (tenantUsers) {
                  let user = null;
                  tenantUsers.forEach(function(tenantUser) {
                      if (tenantUser.aps && tenantUser.aps.id === userApsId) {
                          user = tenantUser;
                      }
                  });
                  deferred.resolve(user);
          }, deferred.reject);
            return deferred;
        },

        getUserOfferingItem: function (user, counterName, createIfNotExist) {
            var offeringItemName = window.offeringItemsMap[counterName] || '';

            if (!user.offeringItems) {
                user.offeringItems = [];
            }

            var filtered = user.offeringItems.filter(function (oi) {
                return oi.name === offeringItemName;
            });

            if (!filtered.length && createIfNotExist) {
                let offeringItem = new getStateful({name: offeringItemName, limit: 0});
                user.offeringItems.push(offeringItem);
                return offeringItem;
            }

            return filtered[0] || null;
        },

        isStorage: function (counterName) {
            return counterName && this.getCountersToOfferingItems()[counterName].legendSchema === 'storage';
        },

        getTenantVisibleQuotas: function (tenant, areaName = '', allowZeroLimit = true) {
            var visibleQuotas = {},
                availableCounters = this.COUNTERS_AVAILABILITY_MAP[areaName] || [];

            for (var counterName in window.allCounters) {
                if (areaName && !availableCounters.includes(counterName) && availableCounters !== '*') {
                    continue;
                }
                var countersInEditions = window.allCounters[counterName].map(function (counter) {
                    return counter.name;
                });
                // Include the edition base name as well
                countersInEditions.push(counterName);
                countersInEditions.forEach(function (edition) {
                    let hasLimit = tenant.hasOwnProperty(edition) && tenant[edition].hasOwnProperty('limit');
                    if (hasLimit && (allowZeroLimit || tenant[edition].limit)) {
                        visibleQuotas[counterName] = edition;
                    }
                });
            }

            return visibleQuotas;
        },

        initCounters(resourceId) {
            let deferred = new Deferred();
            resourceId = resourceId ||
                (aps.context.vars.tenant && aps.context.vars.tenant.aps.id) ||
                (aps.context.vars.enduser && aps.context.vars.enduser.tenant && aps.context.vars.enduser.tenant.aps.id) ||
                (aps.context.vars.globals && aps.context.vars.globals.aps.id);
            if (resourceId) {
                xhr.get("/aps/2/resources/" + resourceId + "/allCounters").then(function (allCountersInfo) {
                    window.allCounters = allCountersInfo['counters'];
                    window.countersMeta = allCountersInfo['counters_meta'];
                    window.offeringItemsMap = [];
                    Object.entries(allCountersInfo['counters_meta']).forEach(function ([counterName, counterMeta]) {
                        window.offeringItemsMap[counterName] = counterMeta['offering_item_name'];
                    });
                    deferred.resolve();
                }, deferred.reject);
            } else {
                deferred.resolve();
            }

            return deferred;
        },

        getFullCountersList() {
            var list = [];
            for (var standardCounterName in window.allCounters) {
                list.push(standardCounterName);
                var counterEditions = window.allCounters[standardCounterName].map(function (counter) {
                    return counter.name;
                });
                list = list.concat(counterEditions);
            }

            return list;
        },

        isBackupAccountResource: function (resource) {
            var editionProperties = this.COUNTERS_AVAILABILITY_MAP["user_quotas"],
                allowedApsType = this.TYPES.TENANT,
                standardCounterName = this.getStandardCounterName(resource.property);

            return editionProperties.some(function (possibleProperty) {
                return resource.apsType === allowedApsType && standardCounterName === possibleProperty;
            });
        },

        getStandardCounterName(counterName) {
            for (var standardCounterName in window.allCounters) {
                var countersInEditions = window.allCounters[standardCounterName].map(function (counter) {
                    return counter.name;
                });
                // Include the edition base name as well
                countersInEditions.push(standardCounterName);
                if (countersInEditions.indexOf(counterName) !== -1) {
                    return standardCounterName;
                }
            }

            return false;
        },

        getAvailableCountersForArea: function (areaName, assoc = false) {
            var allCounters = window.allCounters,
                result = assoc ? {} : [],
                availableCounters = this.COUNTERS_AVAILABILITY_MAP[areaName] || [],
                isForUser = this.USER_AREAS[areaName],
                offeringItemsMap = this.getCountersToOfferingItems();

            for (let [counterName, counterData] of Object.entries(offeringItemsMap)) {
                if (areaName && !availableCounters.includes(this.getStandardCounterName(counterName)) && availableCounters !== '*') {
                    continue;
                }


                var legendSchemaName = counterData.legendSchema || '',
                    predefinedLegendSchemas = this.COUNTERS_LEGEND_SCHEMAS(),
                    legendDefaults = predefinedLegendSchemas[legendSchemaName] || {},
                    counter = lang.mixin(counterData, {
                        name: counterName,
                        legend: counterData.legend || legendDefaults
                    });

                if (isForUser &&
                    allCounters[counterName] !== undefined &&
                    allCounters[counterName]['is_for_user']) {
                    continue;
                }

                if (assoc) {
                    result[counterName] = counter;
                } else {
                    result.push(counter);
                }
            }

            return result;
        },

        getCounterData: function (counterName) {
            return this.getAvailableCountersForArea('', true)[counterName];
        },

        USER_QUOTA: {
            OFF: 0,
            STRICT: 1,
            SOFT: 2
        },

        USER_PRIVILEGED: {
            NO: 0,
            YES: 1
        },

        STATUS: {
            INACTIVE: "-1",
            DISABLED: "0",
            ENABLED: "1"
        },

        NOTIFICATION_LEVEL: {
            OFF: 0,
            LESS: 1,
            MORE: 3,
            ALL: 7
        },

        // required because APS doesn't store empty arrays, and we need to distinguish between "empty" and "not set"
        EMPTY_NOTIFICATIONS: ["false"],

        NOTIFICATION: {
            QUOTA: "quota",
            REPORTS: "reports",
            BACKUP_ERROR: "backup_error",
            BACKUP_WARNING: "backup_warning",
            BACKUP_INFO: "backup_info",
            BACKUP_DAILY_REPORT: "backup_daily_report"
        },

        RESELLER_NOTIFICATIONS: [
            "quota",
            "reports",
            "backup_daily_report"
        ],

        NOTIFICATION_MANAGEMENT: {
            DISABLE: false,
            ENABLE: true
        },

        STORAGE_POLICY: {
            PARENT: "0",
            OWN: "1"
        },

        STORAGE_INHERITED: {
            NO: 0,
            YES: 1
        },

        TYPES: {
            USERS: "http://acronis.com/aps/cloud-backup-v1/users/7.13",
            TENANT: "http://acronis.com/aps/cloud-backup-v1/tenant/9.8",
            GLOBALS: "http://acronis.com/aps/cloud-backup-v1/globals/9.6",
            RESELLER: "http://acronis.com/aps/cloud-backup-v1/reseller/1.0",
            PROFILE: "http://acronis.com/aps/cloud-backup-v1/backup-profile/5.1",
            DATACENTER: "http://acronis.com/aps/cloud-backup-v1/datacenter/4.1",
            ADMIN: "http://acronis.com/aps/cloud-backup-v1/admin/4.0",
            MINIMAL_COMMITMENT_TIER: "http://acronis.com/aps/cloud-backup-v1/minimal-commitment-tier/4.0"
        },

        USER_STATUS: {
            ERROR: "-1",
            INACTIVE: "0",
            ACTIVE: "1",
            IN_PROGRESS: "2",
            NOT_ACTIVATED: "3"
        },

        BACKUP_LOCATIONS: {
            ONLY_CLOUD: "0",
            LOCAL_AND_CLOUD: "1"
        },

        PACKAGE_TYPE: {
            PREMIUM: 'premium'
        },
        GROUP_TYPE: {
            CUSTOMER: "0",
            PARTNER: "1"
        },
        TENANT_TYPE: {
            RESELLER: "RESELLER",
            CUSTOMER: "CUSTOMER",
            PARTNER: "PARTNER"
        },
        TENANT_EDITIONS: {
            ADVANCED: "Adv",
            PROTECT_ADVANCED: "PAdv",
            DISASTER_RECOVERY: "Dre",
            PROTECT_DISASTER_RECOVERY: "PDre",
            PROTECT: "P"
        },

        formatStorageSize: function (value) {
            var units = [_('B'), _('KB'), _('MB'), _('GB'), _('TB'), _('PB'), _('EB')];
            var multiplier = 1024;
            while (value >= multiplier) {
                value = value / multiplier;
                units.shift();
            }
            var decimalPlaces = 1;
            value = Number(value);
            value = value.toFixed(decimalPlaces) == Math.round(value) ? Math.round(value) : value.toFixed(decimalPlaces);
            return value + " " + units.shift();
        },

        isCcpV1: function () {
            return this.getCurrentView().startsWith('ccp');
        },

        printNotification: function (notifications, value) {
            return this.transformNotificationsToArray(notifications, []).includes(value) ? _('Yes') : _('No');
        },

        transformNotificationsToObject: function (notifications) {
            if (!Array.isArray(notifications)) {
                return {};
            }

            var notificationsObj = {};
            Object.values(this.NOTIFICATION).forEach(function (name) {
                notificationsObj[name] = false;
            });

            if (equals(notifications, this.EMPTY_NOTIFICATIONS)) {
                return notificationsObj;
            }

            notifications.forEach(function (name) {
                if (name in notificationsObj) {
                    notificationsObj[name] = true;
                }
            });

            return notificationsObj;
        },

        transformNotificationsToArray: function (notifications, emptyValue) {
            emptyValue = emptyValue || this.EMPTY_NOTIFICATIONS;
            if (Array.isArray(notifications)) {
                return notifications;
            }

            if (!notifications) {
                return emptyValue;
            }

            var notificationsArray = [];
            var validNotifications = Object.values(this.NOTIFICATION);

            Object.keys(notifications).forEach(function (name) {
                if (validNotifications.includes(name) && notifications[name]) {
                    notificationsArray.push(name);
                }
            });

            return notificationsArray.length ? notificationsArray : emptyValue;
        },

        formatLocalDateString: function (date, locale) {
            locale = locale.replace('_', '-');
            try {
                return date.toLocaleString(locale);
            } catch (e) {
                return date.toLocaleString();
            }
        },

        escapeAngularBrackets: function (string) {
            return string ? string.replace(/</g, '&lt;').replace(/>/g, '&gt;') : string;
        },

        getRelatedViewId: function (view) {
            var uri = this.getCurrentView();
            if (uri === undefined) {
                return view;
            }
            var parts = uri.split('--').slice(0, -1);
            parts.push(view);
            return parts.join('--');
        },

        getCurrentView: function () {
            return typeof aps.context.viewId === "undefined" ? aps.context.view.id.split('#').pop() : aps.context.viewId;
        },

        getLanguage: function (locale) {
            return locale.replace(/_.*/, '');
        },

        cmpType: function (originType, inheritType) {
            var regexp = new RegExp(/^(.+\/)(\d+.\d+)$/);
            var originMatches = regexp.exec(originType);
            if (!originMatches || originMatches.length !== 3) {
                return false;
            }

            var inheritMatches = regexp.exec(inheritType);
            if (!inheritMatches || inheritMatches.length !== 3) {
                return false;
            }

            var originURI = originMatches[1],
                inheritURI = inheritMatches[1];

            return originURI === inheritURI;
        },

        isUsers: function (apsType) {
            return this.cmpType(apsType, this.TYPES.USERS);
        },

        isTenant: function (apsType) {
            return this.cmpType(apsType, this.TYPES.TENANT);
        },

        isGlobals: function (apsType) {
            return this.cmpType(apsType, this.TYPES.GLOBALS);
        },

        isReseller: function (apsType) {
            return this.cmpType(apsType, this.TYPES.RESELLER);
        },

        isProfile: function (apsType) {
            return this.cmpType(apsType, this.TYPES.PROFILE);
        },

        getBackupProfile: function (tenant) {
            var deferred = new Deferred();
            var store = new Store({target: "/aps/2/resources/" + tenant.aps.id + "/profile"});
            if (tenant.profile) {
                deferred.resolve(tenant.profile);
            } else {
                store.query().then(function (profiles) {
                    profiles && profiles.length ? deferred.resolve(profiles[0]) : deferred.resolve(null);
                }, deferred.reject);
            }
            return deferred;
        },

        getUserQuota: function (profile) {
            return profile ? Number(profile.userQuota) : this.USER_QUOTA.STRICT;
        },

        getMinimalCommitmentLevelName: function (level) {
            var n = parseInt(level, 10);
            if (isNaN(n)) return '';
            if (n < -1) return _("Fixed custom commitment");
            if (n == -1) return _("No commitment");
            if (n === 0) return _("Minimum");
            return String(n);
        },
        genId: function (widgetType) {
            return dijit.registry.getUniqueId(widgetType);
        },
        loginToConsole: function (backupAccount) {
            var deferred = new Deferred();
            if (!backupAccount) {
                deferred.reject();
                return deferred;
            }
            xhr.get("/aps/2/resources/" + backupAccount.aps.id + "/loginByToken").then(function (uri) {
                deferred.resolve(uri);
            }, deferred.reject);

            return deferred;
        }
    };
});



