/**
 * @Copyright © 2002-2020 Acronis International GmbH. All rights reserved
 */

define([
    'aps/Tile',
    'aps/FieldSet',
    'aps/Output',
    "dojo/_base/lang",
    './../utils',
    './../../common',
    './getResourceOutput',
    './getStorageOutput',
    './getTenantButtons',
    "./js/quotas.js"
], function (
    Tile,
    FieldSet,
    Output,
    lang,
    utils,
    common,
    getResourceOutput,
    getStorageOutput,
    getTenantButtons,
    quotas
) {

    function getCountersByPriority(countersList) {

        for (var i in countersList) {
            countersList[i].sortIndex = window.countersMeta.hasOwnProperty(countersList[i].name) ? window.countersMeta[countersList[i].name]['sorting_index'] : 0;
        }

        countersList.sort(function (a, b) {
            return a.sortIndex - b.sortIndex;
        });

        return countersList;
    }

    function createFieldSet(tenant, countersList) {
        var fs = new FieldSet({
            gridSize: 'md-12 xs-12'
        });

        countersList = getCountersByPriority(countersList);
        countersList.forEach(function (counter) {
            var isSecondary = counter.name.indexOf('Secondary') > -1;
            if (isSecondary) {
                var primaryCounterName = counter.name.replace('Secondary', '');
            }
            if (tenant[counter.name] && (tenant[counter.name].limit || (tenant[primaryCounterName] && tenant[primaryCounterName].limit))) {
                var limit = isSecondary ? -1 : 0;
                var tileData = lang.mixin({
                    gridSize: 'md-4 xs-12',
                    label: quotas.formatStorageLabel(counter.label, false)
                }, counter.legend);

                switch (counter.legendSchema) {
                    case 'feature':
                        fs.addChild(new Output(lang.mixin({
                            value: _('Enabled')
                        }, tileData)));
                        break;
                    case 'storage':
                        fs.addChild(getStorageOutput(lang.mixin({
                            usage: tenant[counter.name].usage || 0,
                            limit: tenant[counter.name].limit || limit || 0
                        }, tileData)));
                        break;
                    default:
                        fs.addChild(getResourceOutput(lang.mixin({
                            usage: tenant[counter.name].usage || 0,
                            limit: tenant[counter.name].limit || limit || 0
                        }, tileData)));
                }
            }
        });

        return fs;
    }

    function getTenantResourcesTile(tenant, subscriptionId, trial, canAdjustLimits, countersList) {

        var buttons = getTenantButtons(tenant, subscriptionId, trial, canAdjustLimits),
            tile = new Tile({
                title: '',
                gridSize: 'md-12 xs-12',
                buttons: [buttons]
            });

        tile.addChild(createFieldSet(tenant, countersList));

        return tile;
    }

    return getTenantResourcesTile;
});

