/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

require([
    "aps/Button",
    "aps/load",
    "aps/Memory",
    "aps/ResourceStore",
    "aps/xhr",
    "dijit/registry",
    "dojo/promise/all",
    "./js/common.js",
    "./js/messages.js",
    "./js/wizardData.js"
], function (
    Button,
    load,
    Memory,
    Store,
    xhr,
    registry,
    all,
    common,
    messages,
    wizardData
) {

    function output(html, id) {
        return ["aps/Output", {value: html, escapeHTML: false, id: id}];
    }

    function image(src) {
        return '<img src=' + src + '>';
    }

    function div(html, cssClass) {
        return '<div class=' + cssClass + '>' + html + '</div>';
    }

    var tenantId = aps.context.vars.tenant.aps.id,
        storages,
        servicePlansStore = new Store({
            target: "/aps/2/resources/" + tenantId + "/plans"
        }),
        storagesStore = new Store({
            target: "/aps/2/resources/" + tenantId + "/storages"
        }),
        columns = [
            {
                field: "name",
                name: _("Service Plan name"),
                sortable: false
            },
            {
                field: "planId",
                name: _("ID"),
                sortable: false
            },
            {
                field: "storageId",
                name: _("Storage"),
                sortable: false,
                escapeHTML: false,
                renderCell: function (row, data) {
                    if (row.storagePolicy == common.STORAGE_POLICY.PARENT) {
                        return _("Provider's storage");
                    }
                    if (data) {
                        return common.escapeAngularBrackets(_("__storageName__ (__datacenterName__)", {
                            storageName: row.storageName,
                            datacenterName: row.datacenterName
                        }));
                    }

                    return image("images/statuses/warning24.png") + " " + _("Not assigned");
                }
            },
            {
                field: "storageId",
                name: _(""),
                escapeHTML: false,
                sortable: false,
                align: "right",
                renderCell: function (row, data) {
                    if (row.storagePolicy == common.STORAGE_POLICY.PARENT) {
                        return "";
                    }

                    return new Button({
                        iconClass: "sb-modify-selected",
                        label: data ? _("Edit") : _("Assign"),
                        onClick: function () {
                            if (storages.length) {
                                var viewId = common.getRelatedViewId('edit');
                                wizardData.setWizardData(row, viewId);
                                aps.apsc.gotoView(viewId);
                            } else {
                                messages.displayWarning(_("There is no storage to assign to the service plan."));
                                this.cancel();
                            }
                        }
                    });
                }
            }
        ],
        widgets = ["aps/PageContainer", {id: "apsPageContainer", "class": "acronis-administrator"}, [
            ["aps/Container", {
                id: "informationContainer",
                title: _("Information"),
                visible: false
            }, [
                output([
                    div(_("You may use your own storage to keep the customers' data there."), ""),
                    div(_("The storage can be registered in the management console."), "info")
                ].join(""))
            ]],
            ["aps/Container", {
                id: "servicePlanContainer",
                title: _("Service Plans"),
                visible: false
            }, [
                output([
                    div([
                        image("images/statuses/warning24.png"),
                        _("Subscription provisioning will fail for Service Plans without storage assigned.")
                    ].join(" "), "info")
                ], "notAssignedWarning"),
                ["aps/Grid", {
                    id: "servicePlansGrid",
                    showPaging: false,
                    pageSizeOptions: "GRID_UNLIMITED",
                    columns: columns
                }]
            ]]
        ]];

    load(widgets).then(function () {
        all({
            plans: servicePlansStore.query(),
            storages: storagesStore.query()
        }).then(function (result) {
            var plans = result.plans,
                notAssignedExist = plans.some(function (plan) {
                    return plan.storagePolicy == common.STORAGE_POLICY.OWN && !plan.storageId;
                });

            storages = result.storages;

            registry.byId("servicePlanContainer").set("visible", true);
            registry.byId("informationContainer").set("visible", true);
            registry.byId("servicePlansGrid").set("store", new Memory({data: plans, idProperty: "planId"}));
            registry.byId("notAssignedWarning").set("visible", notAssignedExist);
        }, messages.displayError);
    });
});