<?php
/**
 * @Copyright © 2002-2018 Acronis International GmbH. All rights reserved
 */

namespace Acronis\App\CloudApi;

use Acronis\App\Services\BuildInfo\BuildInfoAwareTrait;
use Acronis\App\Services\Config\ConfigAwareTrait;
use Acronis\App\Services\Config\ConfigSchema;
use Acronis\App\Services\Logger\LoggerAwareTrait;
use Str;
use Acronis\Cloud\Client\ApiClient;
use Acronis\Cloud\Client\Configuration;

abstract class BaseApi
{
    use LoggerAwareTrait,
        BuildInfoAwareTrait,
        ConfigAwareTrait;

    const ENABLE_DEBUG = true;
    const USER_AGENT_TEMPLATE = 'Acronis-Aps-Package-version-%s';
    const ACRONIS_CUSTOM_HEADER = 'X-Acronis-API';

    /** @var ApiClient */
    private $apiClient;

    /** @var string */
    private $userAgent;

    /**
     * @return string
     */
    abstract protected function getServerUrl();

    /**
     * @param string $url
     * @return ApiClient
     */
    protected function createApiClient($url)
    {
        $apiClientConfig = new Configuration();
        $apiClientConfig->setHost($url);
        $apiClientConfig->setUserAgent($this->getUserAgent());
        $apiClientConfig->setLogger($this->getLogger());

        // todo move it to logger functionality
        $apiClientConfig->setRequestId(\Log::getRequestId());

        $apiClientConfig->setSSLVerification($this->getVerifySsl());
        $apiClientConfig->setDebug(static::ENABLE_DEBUG);
        $apiClientConfig->addDefaultHeader(static::ACRONIS_CUSTOM_HEADER, 1);

        return new ApiClient($apiClientConfig);
    }

    /**
     * @return ApiClient
     */
    protected function getApiClient()
    {
        if (!$this->apiClient) {
            $this->apiClient = $this->createApiClient($this->getServerUrl());
        }
        return $this->apiClient;
    }

    private function getUserAgent()
    {
        if (is_null($this->userAgent)) {
            $this->userAgent = Str::format(
                static::USER_AGENT_TEMPLATE,
                $this->getBuildInfo()->getPackageVersion()
            );
        }

        return $this->userAgent;
    }

    protected function getAccessTokenTtl()
    {
        return $this->getConfig()->getCloudApiConfig()[ConfigSchema::NODE_CLOUD_API_ACCESS_TOKEN_TTL];
    }

    private function getVerifySsl()
    {
        return $this->getConfig()->getCloudApiConfig()[ConfigSchema::NODE_CLOUD_API_VERIFY_SSL];
    }
}