<?php
/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

namespace Acronis\App\CloudApi;

use Acronis\Cloud\Client\Model\Users\User;
use Model_PropertyConverters_UsersConverterHelper as UsersConverterHelper;

class CloudUserObject
{
    /**
     * @var string
     */
    public $id;

    /**
     * @var string
     */
    public $firstName = '';

    /**
     * @var string
     */
    public $lastName = '';

    /**
     * @var string
     */
    public $email = '';

    /**
     * @var string
     */
    public $login;

    /**
     * @var int
     */
    public $status;

    /**
     * @var \Acronis\Cloud\Client\Model\Common\Types\UserNotification[]
     */
    public $notifications;

    /**
     * @var string
     */
    public $datacenterId;

    /**
     * @var string
     */
    public $datacenterName;

    public function __construct(User $user, $datacenterId, $datacenterName)
    {
        $this->id = $user->hasId() ? $user->getId() : '';
        if ($user->hasContact()) {
            $contact = $user->getContact();
            $this->firstName = $contact->hasFirstname() ? $contact->getFirstname() : '';
            $this->lastName = $contact->hasLastname() ? $contact->getLastname() : '';
            $this->email = $contact->hasEmail() ? $contact->getEmail() : '';
        }
        $this->login = $user->hasLogin() ? $user->getLogin() : '';
        $this->status = UsersConverterHelper::getUserStatus($user->getEnabled(), $user->getActivated());
        $this->notifications = $user->hasNotifications() ? $user->getNotifications() : [];
        $this->datacenterId = $datacenterId;
        $this->datacenterName = $datacenterName;
    }
}