<?php

/**
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */
class Model_ConnectionChecker_BaasCredentials implements Model_ConnectionChecker_CheckerInterface
{
    const LOGIN = 'login';

    const ACCOUNT_WITH_LOGIN_NOT_FOUND = 'Account with login %s not found';

    /** @var string */
    private $_partnerLogin;
    /** @var string */
    private $_partnerPassword;
    /** @var string */
    private $_baasUrl;
    /** @var Service_MspApiClient_ApiInterface $mspApi */
    private $_mspApi;
    /** @var int */
    private $_errorCode = 0;
    /** @var string */
    private $_errorMessage = '';

    /**
     * @param string $partnerLogin
     * @param string $partnerPassword
     * @param string $baasUrl
     * @param Service_MspApiClient_ApiInterface $mspApi
     */
    public function __construct($partnerLogin, $partnerPassword, $baasUrl, Service_MspApiClient_ApiInterface $mspApi)
    {
        $this->_partnerLogin = $partnerLogin;
        $this->_partnerPassword = $partnerPassword;
        $this->_baasUrl = $baasUrl;
        $this->_mspApi = $mspApi;
    }

    /**
     * @throws Exception
     * @return bool
     */
    public function check()
    {
        $this->_errorCode = 0;
        $this->_errorMessage = '';

        try {
            $this->_mspApi->setCredentials($this->_partnerLogin, $this->_partnerPassword, $this->_baasUrl, true);
            $this->_mspApi->login();
            return true;
        } catch (Service_BaseClient_HTTPException $e) {
            $this->_errorCode = $e->getCode();
            $this->_errorMessage = ($e->getCode() == 401) ?
                Str::format(self::ACCOUNT_WITH_LOGIN_NOT_FOUND, $this->_partnerLogin) :
                $e->getMessage();
            return false;
        } catch (Exception $e) {
            $this->_errorCode = $e->getCode();
            $this->_errorMessage = $e->getMessage();
            return false;
        }
    }

    /**
     * @return array
     */
    public function getCheckDescription()
    {
        return (object)array(
            self::MESSAGE => _('Verifying authorization for __login__'),
            self::KEYS => (object)array(
                self::LOGIN => $this->_partnerLogin
            )
        );
    }

    /**
     * @return array
     */
    public function getCheckError()
    {
        return (object)array(
            self::CODE => $this->_errorCode,
            self::MESSAGE => $this->_errorMessage
        );
    }
}
