<?php
/**
 * @Copyright © 2002-2018 Acronis International GmbH. All rights reserved
 */

use Service_AmsApiClient_Response_Struct_PersonifiedAgent as PersonifiedAgent;
use Service_AmsApiClient_Response_Struct_PersonifiedGuide as PersonifiedGuide;
use Service_AmsApiClient_Response_Struct_PersonifiedLinks as PersonifiedLinks;

class Service_AmsApiClient_Response_PersonifiedLinks extends Service_BaseClient_Response_Base
{
    const PROPERTY_AGENTS = 'agents';
    const PROPERTY_USER_GUIDE = 'user_guide';
    const PROPERTY_ADMIN_GUIDE = 'admin_guide';

    const FIElD_ARCHITECTURE = 'architecture';
    const FIELD_LANGUAGE = 'language';
    const FIELD_PERSONIFIED = 'personified';
    const FIELD_REAL_LANGUAGE = 'real_language';
    const FIELD_SIZE = 'size';
    const FIELD_SYSTEM = 'system';
    const FIELD_TITLE = 'title';
    const FIELD_TYPE = 'type';
    const FIELD_URL = 'url';
    const FIELD_WEB = 'web';

    /**
     * @param array $responseData
     * @return PersonifiedLinks
     * @throws Exception
     */
    protected function _init(array $responseData)
    {
        $links = new PersonifiedLinks();
        $links->setAgents($this->_initAgent($this->_getProperty(self::PROPERTY_AGENTS, $responseData)));
        $links->setUserGuide($this->_initGuide($this->_getProperty(self::PROPERTY_USER_GUIDE, $responseData)));
        $links->setAdminGuide($this->_initGuide($this->_getProperty(self::PROPERTY_ADMIN_GUIDE, $responseData)));
        return $links;
    }

    /**
     * @param array $agentsData
     * @return PersonifiedAgent[]
     * @throws Exception
     */
    protected function _initAgent(array $agentsData)
    {
        $agents = [];
        foreach ($agentsData as $agentData) {
            $agent = new PersonifiedAgent();
            $agent->setArchitecture($this->_getProperty(self::FIElD_ARCHITECTURE, $agentData, false));
            $agent->setLanguage($this->_getProperty(self::FIELD_LANGUAGE, $agentData, false));
            $agent->setPersonified($this->_getProperty(self::FIELD_PERSONIFIED, $agentData, false));
            $agent->setRealLanguage($this->_getProperty(self::FIELD_REAL_LANGUAGE, $agentData, false));
            $agent->setSize($this->_getProperty(self::FIELD_SIZE, $agentData, false));
            $agent->setSystem($this->_getProperty(self::FIELD_SYSTEM, $agentData, false));
            $agent->setTitle($this->_getProperty(self::FIELD_TITLE, $agentData, false));
            $agent->setType($this->_getProperty(self::FIELD_TYPE, $agentData, false));
            $agent->setUrl($this->_getProperty(self::FIELD_URL, $agentData, false));
            $isWeb = $this->_getProperty(self::FIELD_WEB, $agentData, false);
            $isWeb = is_null($isWeb) ? null : $isWeb === 'true';
            $agent->setWeb($isWeb);

            $agents[] = $agent;
        }

        return $agents;
    }

    /**
     * @param array $agentsData
     * @return PersonifiedGuide[]
     * @throws Exception
     */
    protected function _initGuide(array $agentsData)
    {
        $agents = [];
        foreach ($agentsData as $agentData) {
            $agent = new PersonifiedGuide();
            $agent->setLanguage($this->_getProperty(self::FIELD_LANGUAGE, $agentData, false));
            $agent->setSize($this->_getProperty(self::FIELD_SIZE, $agentData, false));
            $agent->setSystem($this->_getProperty(self::FIELD_SYSTEM, $agentData, false));
            $agent->setTitle($this->_getProperty(self::FIELD_TITLE, $agentData, false));
            $agent->setType($this->_getProperty(self::FIELD_TYPE, $agentData, false));
            $agent->setUrl($this->_getProperty(self::FIELD_URL, $agentData, false));

            $agents[] = $agent;
        }

        return $agents;
    }
}