# Acronis\Cloud\Client\IdpApi

All URIs are relative to *https://localhost:443/api/2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getIdpAuthorize**](IdpApi.md#getIdpAuthorize) | **GET** /idp/authorize | IdpAuthorize
[**getIdpExternalLogin**](IdpApi.md#getIdpExternalLogin) | **GET** /idp/external-login | IdpExternalLogin
[**getIdpKeys**](IdpApi.md#getIdpKeys) | **GET** /idp/keys | IdpKeys
[**getIdpLogout**](IdpApi.md#getIdpLogout) | **GET** /idp/logout | IdpLogout
[**postIdpOtt**](IdpApi.md#postIdpOtt) | **POST** /idp/ott | IdpOtt
[**postIdpOttLogin**](IdpApi.md#postIdpOttLogin) | **POST** /idp/ott/login | IdpOttLogin
[**postIdpToken**](IdpApi.md#postIdpToken) | **POST** /idp/token | IdpToken


# **getIdpAuthorize**
> object getIdpAuthorize($scope, $client_id, $redirect_uri, $response_type, $state, $prompt, $id_token_hint, $login_hint)

IdpAuthorize

OpenID Connect 1.0 Authorization Endpoint. The Authorization Endpoint performs Authentication of the End-User. This is done by sending the User Agent to the Authorization Server's Authorization Endpoint for Authentication and Authorization, using request parameters defined by OAuth 2.0 and additional parameters and parameter values defined by OpenID Connect. See http://openid.net/specs/openid-connect-core-1_0.html#AuthorizationEndpoint for details.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();
$scope = "scope_example"; // string | must contain 'scope' and, optionally, other values separated by spaces
$client_id = "client_id_example"; // string | OAuth 2.0 Client Identifier
$redirect_uri = "redirect_uri_example"; // string | redirection URI to which the response will be sent
$response_type = "response_type_example"; // string | corresponds to OpenID Connect 1.0 or OAuth 2.0 Authorization Flows, our IdP currently supports only Authorization Code Flow
$state = "state_example"; // string | opaque value, which client can use to maintain state between the request and the response callback
$prompt = "prompt_example"; // string | space delimited, case sensitive list of string values that specifies whether the IdP prompts the user for reauthentication and consent; our IdP currently supports only the value below
$id_token_hint = "id_token_hint_example"; // string | ID token previously issued by IdP being passed as a hint about the user current or past authenticated session
$login_hint = "login_hint_example"; // string | Hint to the IdP Server about the login identifier the End-User might use to log in

try {
    $result = $api_instance->getIdpAuthorize($scope, $client_id, $redirect_uri, $response_type, $state, $prompt, $id_token_hint, $login_hint);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->getIdpAuthorize: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **scope** | **string**| must contain &#39;scope&#39; and, optionally, other values separated by spaces |
 **client_id** | **string**| OAuth 2.0 Client Identifier |
 **redirect_uri** | **string**| redirection URI to which the response will be sent |
 **response_type** | **string**| corresponds to OpenID Connect 1.0 or OAuth 2.0 Authorization Flows, our IdP currently supports only Authorization Code Flow | [optional]
 **state** | **string**| opaque value, which client can use to maintain state between the request and the response callback | [optional]
 **prompt** | **string**| space delimited, case sensitive list of string values that specifies whether the IdP prompts the user for reauthentication and consent; our IdP currently supports only the value below | [optional]
 **id_token_hint** | **string**| ID token previously issued by IdP being passed as a hint about the user current or past authenticated session | [optional]
 **login_hint** | **string**| Hint to the IdP Server about the login identifier the End-User might use to log in | [optional]

### Return type

**object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getIdpExternalLogin**
> object getIdpExternalLogin()

IdpExternalLogin

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: auth
Acronis\Cloud\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();

try {
    $result = $api_instance->getIdpExternalLogin();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->getIdpExternalLogin: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

**object**

### Authorization

[auth](../../README.md#auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getIdpKeys**
> \Acronis\Cloud\Client\Model\Idp\Jwks getIdpKeys()

IdpKeys

Returns JSON Web Key Set [JWK] document. See https://tools.ietf.org/html/draft-ietf-jose-json-web-key-41

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();

try {
    $result = $api_instance->getIdpKeys();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->getIdpKeys: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**\Acronis\Cloud\Client\Model\Idp\Jwks**](../Model/Idp/Jwks.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getIdpLogout**
> object getIdpLogout()

IdpLogout

Log out

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: auth
Acronis\Cloud\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();

try {
    $result = $api_instance->getIdpLogout();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->getIdpLogout: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

**object**

### Authorization

[auth](../../README.md#auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postIdpOtt**
> \Acronis\Cloud\Client\Model\Idp\OttLoginPost postIdpOtt($body)

IdpOtt

Method for getting one-time tokens for given user with given purpose. Either user external ID or acronis ID could be supplied. audit_data is abrbitrary optional text field that could be later used for auditing purposes.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: auth
Acronis\Cloud\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();
$body = new \Acronis\Cloud\Client\Model\Idp\OttPost(); // \Acronis\Cloud\Client\Model\Idp\OttPost | 

try {
    $result = $api_instance->postIdpOtt($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->postIdpOtt: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\Acronis\Cloud\Client\Model\Idp\OttPost**](../Model/Idp/OttPost.md)|  |

### Return type

[**\Acronis\Cloud\Client\Model\Idp\OttLoginPost**](../Model/Idp/OttLoginPost.md)

### Authorization

[auth](../../README.md#auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postIdpOttLogin**
> \Acronis\Cloud\Client\Model\Users\User postIdpOttLogin($body)

IdpOttLogin

Login into system using one-time token and get IdP session cookie

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure OAuth2 access token for authorization: auth
Acronis\Cloud\Client\Configuration::getDefaultConfiguration()->setAccessToken('YOUR_ACCESS_TOKEN');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();
$body = new \Acronis\Cloud\Client\Model\Idp\OttLoginPost(); // \Acronis\Cloud\Client\Model\Idp\OttLoginPost | 

try {
    $result = $api_instance->postIdpOttLogin($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->postIdpOttLogin: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\Acronis\Cloud\Client\Model\Idp\OttLoginPost**](../Model/Idp/OttLoginPost.md)|  |

### Return type

[**\Acronis\Cloud\Client\Model\Users\User**](../Model/Users/User.md)

### Authorization

[auth](../../README.md#auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postIdpToken**
> \Acronis\Cloud\Client\Model\Idp\Token postIdpToken($grant_type, $client_id, $username, $password, $refresh_token, $code, $scope, $assertion, $device_code, $totp_code)

IdpToken

OpenID Connect 1.0 and OAuth 2.0 Token Endpoint. To obtain an Access Token, an ID Token, and optionally a Refresh Token, the RP (Client) sends a Token Request to the Token Endpoint to obtain a Token Response, as described in Section 3.2 of OAuth 2.0 [RFC6749], when using the Authorization Code Flow. See http://openid.net/specs/openid-connect-core-1_0.html#TokenEndpoint for details on OpenID Connect 1.0 'authorization_code', 'refresh_token' and 'client_credentials' grant types. See https://tools.ietf.org/html/rfc6749#section-4.3 for details on OAuth2 'password' grant type (Resource Owner Password Credentials Grant). Headers should contain Basic Authorization for 'client_credentials' grant type

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$api_instance = new Acronis\Cloud\Client\Api\IdpApi();
$grant_type = "grant_type_example"; // string | the only always-required parameter; 'password' grant_type implements https://tools.ietf.org/html/rfc6749#section-4.3, 'authorization_code', 'refresh_token' and 'client_credentials' grant_type's implement http://openid.net/specs/openid-connect-core-1_0.html#TokenEndpoint 'urn:ietf:params:oauth:grant-type:device_code' grant type implements https://tools.ietf.org/html/draft-ietf-oauth-device-flow-07 (available only in Backup Account Server) 'urn:ietf:params:oauth:grant-type:jwt-bearer' grant type implements https://tools.ietf.org/html/rfc7523 (available only in Backup Account Server)
$client_id = "client_id_example"; // string | required for grant_type='password' and for grant_type='urn:ietf:params:oauth:grant-type:device_code', not required for other grant_type values
$username = "username_example"; // string | required for 'password' grant_type
$password = "password_example"; // string | required for 'password' grant_type
$refresh_token = "refresh_token_example"; // string | required for 'refresh_token' grant_type
$code = "code_example"; // string | required for 'authorization_code' grant_type
$scope = "scope_example"; // string | Not used for 'authorization_code'. Optional for all other supported grant types.
$assertion = "assertion_example"; // string | required for 'urn:ietf:params:oauth:grant-type:jwt-bearer' grant type
$device_code = "device_code_example"; // string | required for 'urn:ietf:params:oauth:grant-type:device_code' grant type
$totp_code = "totp_code_example"; // string | used with grant_type=password when TOTP authentication is required

try {
    $result = $api_instance->postIdpToken($grant_type, $client_id, $username, $password, $refresh_token, $code, $scope, $assertion, $device_code, $totp_code);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling IdpApi->postIdpToken: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **grant_type** | **string**| the only always-required parameter; &#39;password&#39; grant_type implements https://tools.ietf.org/html/rfc6749#section-4.3, &#39;authorization_code&#39;, &#39;refresh_token&#39; and &#39;client_credentials&#39; grant_type&#39;s implement http://openid.net/specs/openid-connect-core-1_0.html#TokenEndpoint &#39;urn:ietf:params:oauth:grant-type:device_code&#39; grant type implements https://tools.ietf.org/html/draft-ietf-oauth-device-flow-07 (available only in Backup Account Server) &#39;urn:ietf:params:oauth:grant-type:jwt-bearer&#39; grant type implements https://tools.ietf.org/html/rfc7523 (available only in Backup Account Server) |
 **client_id** | **string**| required for grant_type&#x3D;&#39;password&#39; and for grant_type&#x3D;&#39;urn:ietf:params:oauth:grant-type:device_code&#39;, not required for other grant_type values | [optional]
 **username** | **string**| required for &#39;password&#39; grant_type | [optional]
 **password** | **string**| required for &#39;password&#39; grant_type | [optional]
 **refresh_token** | **string**| required for &#39;refresh_token&#39; grant_type | [optional]
 **code** | **string**| required for &#39;authorization_code&#39; grant_type | [optional]
 **scope** | **string**| Not used for &#39;authorization_code&#39;. Optional for all other supported grant types. | [optional]
 **assertion** | **string**| required for &#39;urn:ietf:params:oauth:grant-type:jwt-bearer&#39; grant type | [optional]
 **device_code** | **string**| required for &#39;urn:ietf:params:oauth:grant-type:device_code&#39; grant type | [optional]
 **totp_code** | **string**| used with grant_type&#x3D;password when TOTP authentication is required | [optional]

### Return type

[**\Acronis\Cloud\Client\Model\Idp\Token**](../Model/Idp/Token.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

