<?php
/**
 * @Copyright © 2002-2020 Acronis International GmbH. All rights reserved
 */

namespace Acronis\Common\CodeGenerator\OfferingItems;

use Acronis\Common\CodeGenerator\InterpolatorInterface;
use Twig\Environment;
use Twig\Loader\ArrayLoader;
use Twig\TwigFilter;

class OfferingItemInterpolator implements InterpolatorInterface
{
    private $customFilters = [];

    /**
     * @param string $template
     * @param array $oi
     * @param array $additional
     * @return string
     * @throws \Twig\Error\LoaderError
     * @throws \Twig\Error\RuntimeError
     * @throws \Twig\Error\SyntaxError
     */
    public function interpolate(string $template, $oi, $additional): string
    {
        // To do do not create new TWIG instance each time, try to prepare one per template
        // or even full set of twig templates and use more efficient way
        $loader = new ArrayLoader([
            'template' => $template
        ]);
        $twig = new Environment($loader, ['autoescape' => false, 'optimizations' => 0]);
        foreach ($this->customFilters as $filter) {
            $twig->addFilter($filter);
        }

        $scope = ['oi' => $oi, 'additional' => $additional];

        return $twig->render('template', $scope);
    }

    /**
     * PhpInterpolator constructor.
     */
    public function __construct()
    {
        $this->customFilters[] = new TwigFilter('customUnderscore', function($string) {
            return strtolower(preg_replace('/(?<!^)[A-Z]/', '_$0', $string));
        });
        $this->customFilters[] = new TwigFilter('customJsonWhenArrayOnly', function($value) {
            return is_array($value) ? json_encode($value) : $value;
        });
    }
}