<?php
/**
 * @Copyright © 2002-2020 Acronis International GmbH. All rights reserved
 */

namespace Acronis\Common\CodeGenerator\OfferingItems;


use Acronis\Common\CodeGenerator\Exception\StorageCounterException;

trait StorageCountersTrait
{
    private static $fieldsToAssign = ['counter_name', 'ui_name', 'enables'];
    protected static $optionalFieldsToAssign = ['templates'];

    /**
     * @param $ois
     * @return array
     * @throws StorageCounterException
     */
    private function buildPredefinedStorageFields($ois)
    {
        $oisWithoutHosted = array_filter($ois, function ($oi) {
            return !empty($oi['counter_name']) && !$this->isStorageHostedCounter($oi['counter_name']);
        });
        $storageOis = array_filter($ois, function ($oi) {
            return !empty($oi['name']) && strpos($oi['name'], 'storage') !== false;
        });
        $oiFields = function ($ois, $fieldName) {
            return array_map(function ($oi) use ($fieldName) {
                return $oi[$fieldName];
            }, $ois);
        };

        $oiToCounterNameMapping = array_combine($oiFields($oisWithoutHosted, 'name'), $oiFields($oisWithoutHosted, 'counter_name'));
        $predefinedStorageFields = array_fill_keys($oiFields($storageOis, 'name'), []);

        foreach ($storageOis as $oi) {
            $affix = preg_match('/(?<affix>[A-Z][a-z]*Hosted)/', $oi['counter_name'], $match) ? $match['affix'] : '';
            $oiName = $oi['name'];
            $oiName = str_replace('child_storages', 'storage', $oiName);
            $predefinedStorageFields[$oiName][$affix] = array_intersect_key($oi, array_flip(static::$fieldsToAssign));
            $predefinedStorageFields[$oiName][$affix]['options'] = array_intersect_key($oi['options'] ?? [], array_flip(static::$optionalFieldsToAssign));

            if ($affix) {
                if (!isset($oiToCounterNameMapping[$oiName])) {
                    throw new StorageCounterException($oiName);
                }
            }
        }

        return $predefinedStorageFields;
    }

    protected function isStorageHostedCounter($counterName)
    {
        return preg_match('/(Acronis|Google|Azure|Provider|Partner)Hosted/', $counterName) !== 0;
    }
}