<?php

namespace Acronis\Common\Commands;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\Input;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Yaml\Yaml;

class AssetAwareCommand extends Command
{
    const ARGUMENT_ASSET = 'assets';
    const ARGUMENT_ASSET_DESCRIPTION = 'Name of asset to be generated, referring to section in config.yaml';

    const ARGUMENT_CONFIG = 'config';
    const ARGUMENT_CONFIG_DESCRIPTION = 'Path of local assets config.';

    const ARGUMENT_CODE_BASE_PATH = ' code_base_path';
    const ARGUMENT_CODE_BASE_PATH_DESCRIPTION = 'Bath path for any relative path from asset mappings to source code.';

    protected function configure()
    {
        parent::configure();

        $this->addArgument(
            static::ARGUMENT_ASSET,
            InputArgument::REQUIRED,
            static::ARGUMENT_ASSET_DESCRIPTION
        );

        $this->addArgument(
            static::ARGUMENT_CONFIG,
            InputArgument::OPTIONAL,
            static::ARGUMENT_CONFIG_DESCRIPTION
        );

        $this->addArgument(
            static::ARGUMENT_CODE_BASE_PATH,
            InputArgument::OPTIONAL,
            static::ARGUMENT_CODE_BASE_PATH_DESCRIPTION
        );
    }

    /**
     * @param Input $input
     * @return array|mixed
     */
    protected function loadAssetConfig($input)
    {
        $config = Yaml::parseFile(__DIR__ . '/../CodeGenerator/config.yaml');
        // note: Symfony commands behaviour - when argument is optional and is not provided hasArgument
        // will return true, in this case just check that value is not an empty string
        $localConfigPath = $input->getArgument(static::ARGUMENT_CONFIG);
        if ($localConfigPath) {
            $config = array_merge($config, Yaml::parseFile($localConfigPath));
        }
        $assetName = $input->getArgument(static::ARGUMENT_ASSET);
        $config = $config[$assetName] ?? [];
        $config['base_path'] = ($config['override_base_path'] ?? false) ? dirname(realpath($localConfigPath)) : __DIR__;
        $config['code_base_path'] = $input->getArgument(static::ARGUMENT_CODE_BASE_PATH)
            ? realpath($input->getArgument(static::ARGUMENT_CODE_BASE_PATH))
            : $config['base_path'];

        return $config;
    }

    protected function getAssetName($input)
    {
        return $input->getArgument(static::ARGUMENT_ASSET);
    }
}