<?php
/**
 * @Copyright © 2002-2020 Acronis International GmbH. All rights reserved
 */

namespace Acronis\Common\Commands;

use Acronis\Common\CodeGenerator\CodeGenerator;
use Acronis\Common\CodeGenerator\OfferingItems\OfferingItemInterpolator;
use Acronis\Common\CodeGenerator\OfferingItems\OfferingItemsPreparer;
use Acronis\Common\CodeGenerator\OfferingItems\RequirementsInterpolator;
use Acronis\Common\Utils\CodegenHelper;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class Generate extends AssetAwareCommand
{
    protected $testMode = false;

    public function getName()
    {
        return 'code:generate';
    }

    public function getDescription()
    {
        return <<<TEXT
Use this command to generate some code. 
Read https://adn.acronis.com/display/APS/PHP+Offering+Items+and+Utils+repo (Code generation tool part)
TEXT;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $config = $this->loadAssetConfig($input);
        $assetName = $this->getAssetName($input);
        $templatesPath = realpath($config['base_path'] . $config['templates']);
        $codePath = realpath($config['code_base_path']);

        if ($assetName === 'offering_items') {
            $items = $this->prepareOfferingItems($config);
            $interpolator = new OfferingItemInterpolator();
        } else if ($assetName === 'requirements') {
            $items = $this->getItems($config);
            $interpolator = new RequirementsInterpolator();
        } else {
            throw new \Exception(sprintf('Asset "%s" is not supported', $assetName));
        }

        $codeGen = new CodeGenerator(new CodegenHelper($templatesPath, $codePath,false, false), $interpolator);
        $codeGen->generate($items, $this->testMode);

        echo sprintf('[CODEGEN TOOL] Asset - "%s". Successfully Added source code for %s items.', $assetName, count($items));

        return 0;
    }

    private function prepareOfferingItems($config)
    {
        $itemsSourcePath = $config['base_path'] . $config['items'];
        $schemasSourcePath = $config['base_path'] . $config['schemas'];
        if (!file_exists($itemsSourcePath) || !file_exists($schemasSourcePath)) {
            echo sprintf('[CODEGEN TOOL] One or both required configs "%s" and "%s" does not exist.',
                $itemsSourcePath, $schemasSourcePath
            );
            echo 'Note: it is possible to specify config.yaml path (second argument) which can override location of these files.';

            exit;
        }

        $data = array_merge(
            CodegenHelper::loadItemsFromPath($itemsSourcePath),
            CodegenHelper::loadItemsFromPath($schemasSourcePath)
        );
        $preparer = new OfferingItemsPreparer($data['offering_items'], $data['schemas']);
        return $preparer->setLogFileName($config['base_path'] . $config['preparation_output'])->prepareOfferingItems();
    }

    private function getItems($config)
    {
        return CodegenHelper::loadItemsFromPath($config['base_path'] . $config['items']);
    }
}